==> ejc-procurement-api-3.0.0-20251215.092620-127-sources.jar: com/ejianc/business/procurement/perform/vo/ReviewAnnounceVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 采购前公示结果评审表
 * 
 * @author generator
 * 
 */
public class ReviewAnnounceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer nobidMethod; // 非招标交易方式
    private String memo; // 备注
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Integer supplierResFlag; // 是否存在其他潜在供应商响应
    private Integer bidMethod; // 评标办法
    private BigDecimal budgetTaxMny; // 采购预算
    private Integer publishType; // 采购公开程度：公开、邀请
    private String planObject; // 采购标的
    private String purchaseType; // 采购方式：1-带量；2-入围；3-框架
    private String executePlanName; // 执行计划名称
    private String executePlanCode; // 执行计划编码
    private Long executePlanId; // 执行计划
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    private Integer organizeShape; // 采购组织形式1-自主采购,2-委托采购
    private Integer permissionType; // 实施权限1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private String performWay; // 采购实施方式1-招标，2-非招标
    private String orgCode; // 采购实施单位编码
    private String orgName; // 采购实施单位名称
    private Long orgId; // 采购实施单位Id
    private String purchaseProjectName; // 采购项目名称
    private String purchaseProjectCode; // 采购项目编号
    private Long purchaseProjectId; // 采购项目Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    
    private List<ReviewAnnounceConfirmVO> reviewAnnounceConfirmList = new ArrayList<>(); // 采购前公示结果评审-审查清单

    public Integer getNobidMethod() {
        return nobidMethod;
    }

    public void setNobidMethod(Integer nobidMethod) {
        this.nobidMethod = nobidMethod;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Integer getSupplierResFlag() {
        return supplierResFlag;
    }

    public void setSupplierResFlag(Integer supplierResFlag) {
        this.supplierResFlag = supplierResFlag;
    }

    public Integer getBidMethod() {
        return bidMethod;
    }

    public void setBidMethod(Integer bidMethod) {
        this.bidMethod = bidMethod;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public Integer getPublishType() {
        return publishType;
    }

    public void setPublishType(Integer publishType) {
        this.publishType = publishType;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getExecutePlanName() {
        return executePlanName;
    }

    public void setExecutePlanName(String executePlanName) {
        this.executePlanName = executePlanName;
    }
    public String getExecutePlanCode() {
        return executePlanCode;
    }

    public void setExecutePlanCode(String executePlanCode) {
        this.executePlanCode = executePlanCode;
    }
    @ReferSerialTransfer(referCode = "ejc_procurement_execute_plan")
    public Long getExecutePlanId() {
        return executePlanId;
    }
    @ReferDeserialTransfer
    public void setExecutePlanId(Long executePlanId) {
        this.executePlanId = executePlanId;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public Integer getOrganizeShape() {
        return organizeShape;
    }

    public void setOrganizeShape(Integer organizeShape) {
        this.organizeShape = organizeShape;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public String getPerformWay() {
        return performWay;
    }

    public void setPerformWay(String performWay) {
        this.performWay = performWay;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getPurchaseProjectName() {
        return purchaseProjectName;
    }

    public void setPurchaseProjectName(String purchaseProjectName) {
        this.purchaseProjectName = purchaseProjectName;
    }
    public String getPurchaseProjectCode() {
        return purchaseProjectCode;
    }

    public void setPurchaseProjectCode(String purchaseProjectCode) {
        this.purchaseProjectCode = purchaseProjectCode;
    }
    @ReferSerialTransfer(referCode = "procurement-purchase-project")
    public Long getPurchaseProjectId() {
        return purchaseProjectId;
    }
    @ReferDeserialTransfer
    public void setPurchaseProjectId(Long purchaseProjectId) {
        this.purchaseProjectId = purchaseProjectId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
     public List<ReviewAnnounceConfirmVO> getReviewAnnounceConfirmList() {
        return reviewAnnounceConfirmList;
     }

     public void setReviewAnnounceConfirmList(List<ReviewAnnounceConfirmVO> reviewAnnounceConfirmList) {
        this.reviewAnnounceConfirmList = reviewAnnounceConfirmList;
     }
}

==> ejc-procurement-api-3.0.0-20251217.021048-143-sources.jar: com/ejianc/business/procurement/perform/vo/ReviewAnnounceVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 采购前公示结果评审表
 * 
 * @author generator
 * 
 */
public class ReviewAnnounceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer nobidMethod; // 非招标交易方式
    private String memo; // 备注
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Integer supplierResFlag; // 是否存在其他潜在供应商响应
    private Integer bidMethod; // 评标办法
    private BigDecimal budgetTaxMny; // 采购预算
    private Integer publishType; // 采购公开程度：公开、邀请
    private String planObject; // 采购标的
    private String purchaseType; // 采购方式：1-带量；2-入围；3-框架
    private String executePlanName; // 执行计划名称
    private String executePlanCode; // 执行计划编码
    private Long executePlanId; // 执行计划
    private String businessType; // 业务类别1-工程，2-货物，3-服务
    private Integer organizeShape; // 采购组织形式1-自主采购,2-委托采购
    private Integer permissionType; // 实施权限1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private String performWay; // 采购实施方式1-招标，2-非招标
    private String orgCode; // 采购实施单位编码
    private String orgName; // 采购实施单位名称
    private Long orgId; // 采购实施单位Id
    private String purchaseProjectName; // 采购项目名称
    private String purchaseProjectCode; // 采购项目编号
    private Long purchaseProjectId; // 采购项目Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态

    private String permissionTypeName;
    private String businessTypeName;
    private List<ReviewAnnounceConfirmVO> reviewAnnounceConfirmList = new ArrayList<>(); // 采购前公示结果评审-审查清单

    public String getPermissionTypeName() {
        return permissionTypeName;
    }

    public void setPermissionTypeName(String permissionTypeName) {
        this.permissionTypeName = permissionTypeName;
    }

    public String getBusinessTypeName() {
        return businessTypeName;
    }

    public void setBusinessTypeName(String businessTypeName) {
        this.businessTypeName = businessTypeName;
    }

    public Integer getNobidMethod() {
        return nobidMethod;
    }

    public void setNobidMethod(Integer nobidMethod) {
        this.nobidMethod = nobidMethod;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Integer getSupplierResFlag() {
        return supplierResFlag;
    }

    public void setSupplierResFlag(Integer supplierResFlag) {
        this.supplierResFlag = supplierResFlag;
    }

    public Integer getBidMethod() {
        return bidMethod;
    }

    public void setBidMethod(Integer bidMethod) {
        this.bidMethod = bidMethod;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public Integer getPublishType() {
        return publishType;
    }

    public void setPublishType(Integer publishType) {
        this.publishType = publishType;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public String getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(String purchaseType) {
        this.purchaseType = purchaseType;
    }
    public String getExecutePlanName() {
        return executePlanName;
    }

    public void setExecutePlanName(String executePlanName) {
        this.executePlanName = executePlanName;
    }
    public String getExecutePlanCode() {
        return executePlanCode;
    }

    public void setExecutePlanCode(String executePlanCode) {
        this.executePlanCode = executePlanCode;
    }
    @ReferSerialTransfer(referCode = "ejc_procurement_execute_plan")
    public Long getExecutePlanId() {
        return executePlanId;
    }
    @ReferDeserialTransfer
    public void setExecutePlanId(Long executePlanId) {
        this.executePlanId = executePlanId;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public Integer getOrganizeShape() {
        return organizeShape;
    }

    public void setOrganizeShape(Integer organizeShape) {
        this.organizeShape = organizeShape;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public String getPerformWay() {
        return performWay;
    }

    public void setPerformWay(String performWay) {
        this.performWay = performWay;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getPurchaseProjectName() {
        return purchaseProjectName;
    }

    public void setPurchaseProjectName(String purchaseProjectName) {
        this.purchaseProjectName = purchaseProjectName;
    }
    public String getPurchaseProjectCode() {
        return purchaseProjectCode;
    }

    public void setPurchaseProjectCode(String purchaseProjectCode) {
        this.purchaseProjectCode = purchaseProjectCode;
    }
    @ReferSerialTransfer(referCode = "procurement-purchase-project")
    public Long getPurchaseProjectId() {
        return purchaseProjectId;
    }
    @ReferDeserialTransfer
    public void setPurchaseProjectId(Long purchaseProjectId) {
        this.purchaseProjectId = purchaseProjectId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
     public List<ReviewAnnounceConfirmVO> getReviewAnnounceConfirmList() {
        return reviewAnnounceConfirmList;
     }

     public void setReviewAnnounceConfirmList(List<ReviewAnnounceConfirmVO> reviewAnnounceConfirmList) {
        this.reviewAnnounceConfirmList = reviewAnnounceConfirmList;
     }
}
